This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, dashboard has been updated
       via  cb56d71de1bd40e06db17cb0266d1fbeabea75a3 (commit)
       via  3fc78bb9738930ed6eed5f2be3eeb5e0cecc1b0f (commit)
       via  aa516480fd7b593abbbbb004be7037b114d4191a (commit)
       via  3159d3f588e2842e3d0eb85b410c985203423e2d (commit)
       via  99d55e896516cdadafd6b926921cdf59c2e09fa3 (commit)
      from  182b93635464ee35100522dec811abb76b55c742 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=cb56d71de1bd40e06db17cb0266d1fbeabea75a3
commit cb56d71de1bd40e06db17cb0266d1fbeabea75a3
Author:     Brad King <brad.k...@kitware.com>
AuthorDate: Thu Jan 21 10:27:11 2016 -0500
Commit:     Brad King <brad.k...@kitware.com>
CommitDate: Thu Jan 21 10:30:37 2016 -0500

    cmake_common: Fix use of ctest_empty_binary_directory
    
    Make the build directory after using ctest_empty_binary_directory
    because the command reports an error if asked to delete a directory
    that exists but does not contain `CMakeCache.txt`.
    
    Reported-by: Raffi Enficiaud <raffi.enfici...@tuebingen.mpg.de>

diff --git a/cmake_common.cmake b/cmake_common.cmake
index 322424b..ff91ad1 100644
--- a/cmake_common.cmake
+++ b/cmake_common.cmake
@@ -313,11 +313,12 @@ ${dashboard_cache}
 endmacro(write_cache)
 
 # Start with a fresh build tree.
-file(MAKE_DIRECTORY "${CTEST_BINARY_DIRECTORY}")
-if(NOT "${CTEST_SOURCE_DIRECTORY}" STREQUAL "${CTEST_BINARY_DIRECTORY}")
+if(EXISTS "${CTEST_BINARY_DIRECTORY}" AND
+    NOT "${CTEST_SOURCE_DIRECTORY}" STREQUAL "${CTEST_BINARY_DIRECTORY}")
   message("Clearing build tree...")
   ctest_empty_binary_directory(${CTEST_BINARY_DIRECTORY})
 endif()
+file(MAKE_DIRECTORY "${CTEST_BINARY_DIRECTORY}")
 
 set(dashboard_continuous 0)
 if("${dashboard_model}" STREQUAL "Continuous")

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=3fc78bb9738930ed6eed5f2be3eeb5e0cecc1b0f
commit 3fc78bb9738930ed6eed5f2be3eeb5e0cecc1b0f
Author:     Brad King <brad.k...@kitware.com>
AuthorDate: Fri Aug 28 09:08:52 2015 -0400
Commit:     Brad King <brad.k...@kitware.com>
CommitDate: Thu Jan 21 10:30:05 2016 -0500

    cmake_common: Use CTEST_TEST_ARGS for ctest_memcheck() call
    
    The ctest_memcheck step should run the same tests as the ctest_test
    step.

diff --git a/cmake_common.cmake b/cmake_common.cmake
index 9af724a..322424b 100644
--- a/cmake_common.cmake
+++ b/cmake_common.cmake
@@ -384,7 +384,7 @@ while(NOT dashboard_done)
       ctest_coverage()
     endif()
     if(dashboard_do_memcheck)
-      ctest_memcheck()
+      ctest_memcheck(${CTEST_TEST_ARGS})
     endif()
     if(NOT dashboard_no_submit)
       ctest_submit()

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=aa516480fd7b593abbbbb004be7037b114d4191a
commit aa516480fd7b593abbbbb004be7037b114d4191a
Author:     Brad King <brad.k...@kitware.com>
AuthorDate: Tue May 20 11:44:07 2014 -0400
Commit:     Brad King <brad.k...@kitware.com>
CommitDate: Tue May 20 11:44:07 2014 -0400

    cmake_common: Enable launchers and make program for Ninja generator

diff --git a/cmake_common.cmake b/cmake_common.cmake
index a7b83a0..7b9d91b 100644
--- a/cmake_common.cmake
+++ b/cmake_common.cmake
@@ -364,7 +364,7 @@ while(NOT dashboard_done)
   set(CTEST_CHECKOUT_COMMAND) # checkout on first iteration only
   safe_message("Found ${count} changed files")
   if(dashboard_fresh OR NOT dashboard_continuous OR count GREATER 0)
-    ctest_configure()
+    ctest_configure(${dashboard_configure_args})
     ctest_read_custom_files(${CTEST_BINARY_DIRECTORY})
 
     if(COMMAND dashboard_hook_build)

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=99d55e896516cdadafd6b926921cdf59c2e09fa3
commit 99d55e896516cdadafd6b926921cdf59c2e09fa3
Author:     Brad King <brad.k...@kitware.com>
AuthorDate: Tue May 20 11:43:40 2014 -0400
Commit:     Brad King <brad.k...@kitware.com>
CommitDate: Tue May 20 11:43:40 2014 -0400

    cmake_common: Add dashboard_no_test option

diff --git a/cmake_common.cmake b/cmake_common.cmake
index 576db9a..a7b83a0 100644
--- a/cmake_common.cmake
+++ b/cmake_common.cmake
@@ -375,7 +375,9 @@ while(NOT dashboard_done)
     if(COMMAND dashboard_hook_test)
       dashboard_hook_test()
     endif()
-    ctest_test(${CTEST_TEST_ARGS})
+    if(NOT dashboard_no_test)
+      ctest_test(${CTEST_TEST_ARGS})
+    endif()
     set(safe_message_skip 1) # Block furhter messages
 
     if(dashboard_do_coverage)

-----------------------------------------------------------------------

Summary of changes:
 cmake_common.cmake |   19 +++++++++++--------
 1 file changed, 11 insertions(+), 8 deletions(-)


hooks/post-receive
diff --git a/cmake_common.cmake b/cmake_common.cmake
index 7b9d91b..9af724a 100644
--- a/cmake_common.cmake
+++ b/cmake_common.cmake
@@ -116,8 +116,8 @@ endif()
 if(dashboard_bootstrap)
   # Launchers do not work during bootstrap: no ctest available.
   set(CTEST_USE_LAUNCHERS 0)
-elseif(NOT "${CTEST_CMAKE_GENERATOR}" MATCHES "Make")
-  # Launchers work only with Makefile generators.
+elseif(NOT "${CTEST_CMAKE_GENERATOR}" MATCHES "Make|Ninja")
+  # Launchers work only with Makefile and Ninja generators.
   set(CTEST_USE_LAUNCHERS 0)
 elseif(NOT DEFINED CTEST_USE_LAUNCHERS)
   # The setting is ignored by CTest < 2.8 so we need no version test.
@@ -293,7 +293,7 @@ set(ENV{LC_ALL} C)
 macro(write_cache)
   set(cache_build_type "")
   set(cache_make_program "")
-  if(CTEST_CMAKE_GENERATOR MATCHES "Make")
+  if(CTEST_CMAKE_GENERATOR MATCHES "Make|Ninja")
     set(cache_build_type CMAKE_BUILD_TYPE:STRING=${CTEST_BUILD_CONFIGURATION})
     if(CMAKE_MAKE_PROGRAM)
       set(cache_make_program CMAKE_MAKE_PROGRAM:FILEPATH=${CMAKE_MAKE_PROGRAM})

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=3159d3f588e2842e3d0eb85b410c985203423e2d
commit 3159d3f588e2842e3d0eb85b410c985203423e2d
Author:     Brad King <brad.k...@kitware.com>
AuthorDate: Tue May 20 11:43:53 2014 -0400
Commit:     Brad King <brad.k...@kitware.com>
CommitDate: Tue May 20 11:43:53 2014 -0400

    cmake_common: Add dashboard_configure_args option

-- 
CMake
_______________________________________________
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits

Reply via email to